@@ -18,39 +18,34 @@
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #include "multiagendaview.h"
-#include "configdialoginterface.h"
-#include "prefs.h"
 
+#include "prefs.h"
 #include "agenda/agenda.h"
 #include "agenda/agendaview.h"
 #include "agenda/timelabelszone.h"
+#include "configdialoginterface.h"
+#include "calendarview_debug.h"
+
+#include <AkonadiCore/EntityTreeModel>
+#include <AkonadiWidgets/ETMViewStateSaver>
 
-#include <entitytreemodel.h>
-#include <Akonadi/Calendar/ETMCalendar>
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/Utils>
 
-#include <ETMViewStateSaver>
-
-#include <KCalCore/Event>
-
 #include <KCheckableProxyModel>
 #include <KLocalizedString>
-#include <QVBoxLayout>
+#include <KRearrangeColumnsProxyModel>
 #include <KViewStateMaintainer>
-#include "calendarview_debug.h"
 
 #include <QHBoxLayout>
-#include <QItemSelectionModel>
 #include <QLabel>
+#include <QPainter>
 #include <QResizeEvent>
 #include <QScrollArea>
 #include <QScrollBar>
-#include <QSplitter>
 #include <QSortFilterProxyModel>
+#include <QSplitter>
 #include <QTimer>
-#include <QPainter>
-#include <KRearrangeColumnsProxyModel>
 
 using namespace Akonadi;
 using namespace EventViews;
@@ -97,10 +92,12 @@ static QString generateColumnLabel(int c)
 class Q_DECL_HIDDEN MultiAgendaView::Private
 {
 private:
-    class ElidedLabel: public QFrame
+    class ElidedLabel : public QFrame
     {
     public:
-        ElidedLabel(const QString &text): mText(text) {}
+        ElidedLabel(const QString &text) : mText(text)
+        {
+        }
 
         QSize minimumSizeHint() const override;
 
@@ -112,12 +109,12 @@ private:
     };
 
 public:
-    Private(MultiAgendaView *qq) :
-        q(qq),
-        mUpdateOnShow(true),
-        mPendingChanges(true),
-        mCustomColumnSetupUsed(false),
-        mCustomNumberOfColumns(2)
+    Private(MultiAgendaView *qq)
+        : q(qq)
+        , mUpdateOnShow(true)
+        , mPendingChanges(true)
+        , mCustomColumnSetupUsed(false)
+        , mCustomNumberOfColumns(2)
     {
     }
 
@@ -136,12 +133,14 @@ public:
     MultiAgendaView *q;
     QList<AgendaView *> mAgendaViews;
     QList<QWidget *> mAgendaWidgets;
-    QWidget *mTopBox;
-    QScrollArea *mScrollArea;
-    TimeLabelsZone *mTimeLabelsZone;
-    QSplitter *mLeftSplitter, *mRightSplitter;
-    QScrollBar *mScrollBar;
-    QWidget *mLeftBottomSpacer, *mRightBottomSpacer;
+    QWidget *mTopBox = nullptr;
+    QScrollArea *mScrollArea = nullptr;
+    TimeLabelsZone *mTimeLabelsZone = nullptr;
+    QSplitter *mLeftSplitter = nullptr;
+    QSplitter *mRightSplitter = nullptr;
+    QScrollBar *mScrollBar = nullptr;
+    QWidget *mLeftBottomSpacer = nullptr;
+    QWidget *mRightBottomSpacer = nullptr;
     QDate mStartDate, mEndDate;
     bool mUpdateOnShow;
     bool mPendingChanges;
@@ -149,14 +148,14 @@ public:
     QVector<KCheckableProxyModel *> mCollectionSelectionModels;
     QStringList mCustomColumnTitles;
     int mCustomNumberOfColumns;
-    QLabel *mLabel;
-    QWidget *mRightDummyWidget;
-    QHash<QString, KViewStateMaintainer<ETMViewStateSaver>* > mSelectionSavers;
+    QLabel *mLabel = nullptr;
+    QWidget *mRightDummyWidget = nullptr;
+    QHash<QString, KViewStateMaintainer<ETMViewStateSaver> * > mSelectionSavers;
 };
 
 MultiAgendaView::MultiAgendaView(QWidget *parent)
-    : EventView(parent), d(new Private(this))
-
+    : EventView(parent)
+    , d(new Private(this))
 {
     QHBoxLayout *topLevelLayout = new QHBoxLayout(this);
     topLevelLayout->setSpacing(0);
@@ -242,11 +241,12 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
 void MultiAgendaView::setCalendar(const Akonadi::ETMCalendar::Ptr &calendar)
 {
     EventView::setCalendar(calendar);
-    Q_FOREACH (KCheckableProxyModel *proxy, d->mCollectionSelectionModels) {
+    for (KCheckableProxyModel *proxy : qAsConst(d->mCollectionSelectionModels)) {
         proxy->setSourceModel(calendar->entityTreeModel());
     }
 
-    disconnect(nullptr, SIGNAL(selectionChanged(Akonadi::Collection::List,Akonadi::Collection::List)),
+    disconnect(nullptr,
+               SIGNAL(selectionChanged(Akonadi::Collection::List,Akonadi::Collection::List)),
                this, SLOT(forceRecreateViews()));
 
     connect(collectionSelection(), &CalendarSupport::CollectionSelection::selectionChanged,
@@ -457,8 +457,7 @@ void MultiAgendaView::slotSelectionChanged()
     }
 }
 
-bool MultiAgendaView::eventDurationHint(QDateTime &startDt, QDateTime &endDt,
-                                        bool &allDay) const
+bool MultiAgendaView::eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const
 {
     foreach (AgendaView *agenda, d->mAgendaViews) {
         bool valid = agenda->eventDurationHint(startDt, endDt, allDay);
@@ -542,8 +541,7 @@ void MultiAgendaView::resizeEvent(QResizeEvent *ev)
 
 void MultiAgendaView::Private::resizeScrollView(const QSize &size)
 {
-    const int widgetWidth = size.width() - mTimeLabelsZone->width() -
-                            mScrollBar->width();
+    const int widgetWidth = size.width() - mTimeLabelsZone->width() - mScrollBar->width();
 
     int height = size.height();
     if (mScrollArea->horizontalScrollBar()->isVisible()) {
@@ -673,7 +671,6 @@ void MultiAgendaView::collectionSelectionChanged()
 
 bool MultiAgendaView::hasConfigurationDialog() const
 {
-
     /** The wrapper in korg has the dialog. Too complicated to move to CalendarViews.
         Depends on korg/AkonadiCollectionView, and will be refactored some day
         to get rid of CollectionSelectionProxyModel/EntityStateSaver */
@@ -690,7 +687,7 @@ void MultiAgendaView::doRestoreConfig(const KConfigGroup &configGroup)
 
     d->mCustomColumnSetupUsed = configGroup.readEntry("UseCustomColumnSetup", false);
     d->mCustomNumberOfColumns = configGroup.readEntry("CustomNumberOfColumns", 2);
-    d->mCustomColumnTitles =  configGroup.readEntry("ColumnTitles", QStringList());
+    d->mCustomColumnTitles = configGroup.readEntry("ColumnTitles", QStringList());
     if (d->mCustomColumnTitles.size() != d->mCustomNumberOfColumns) {
         const int orig = d->mCustomColumnTitles.size();
         d->mCustomColumnTitles.reserve(d->mCustomNumberOfColumns);
@@ -713,7 +710,8 @@ void MultiAgendaView::doRestoreConfig(const KConfigGroup &configGroup)
 
             // Only show the first column
             KRearrangeColumnsProxyModel *columnFilterProxy = new KRearrangeColumnsProxyModel(this);
-            columnFilterProxy->setSourceColumns(QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
+            columnFilterProxy->setSourceColumns(
+                QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
             columnFilterProxy->setSourceModel(sortProxy);
 
             // Keep track of selection.
@@ -723,11 +721,13 @@ void MultiAgendaView::doRestoreConfig(const KConfigGroup &configGroup)
             KCheckableProxyModel *checkableProxy = new KCheckableProxyModel(this);
             checkableProxy->setSourceModel(columnFilterProxy);
             checkableProxy->setSelectionModel(qsm);
-            const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(i);
+            const QString groupName
+                = configGroup.name() + QLatin1String("_subView_") + QString::number(i);
             const KConfigGroup group = configGroup.config()->group(groupName);
 
             if (!d->mSelectionSavers.contains(groupName)) {
-                d->mSelectionSavers.insert(groupName, new KViewStateMaintainer<ETMViewStateSaver>(group));
+                d->mSelectionSavers.insert(groupName,
+                                           new KViewStateMaintainer<ETMViewStateSaver>(group));
                 d->mSelectionSavers[groupName]->setSelectionModel(checkableProxy->selectionModel());
             }
 
@@ -748,13 +748,15 @@ void MultiAgendaView::doSaveConfig(KConfigGroup &configGroup)
     configGroup.writeEntry("ColumnTitles", d->mCustomColumnTitles);
     int idx = 0;
     foreach (KCheckableProxyModel *checkableProxyModel, d->mCollectionSelectionModels) {
-        const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(idx);
+        const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(
+            idx);
         KConfigGroup group = configGroup.config()->group(groupName);
         ++idx;
         //TODO never used ?
         KViewStateMaintainer<ETMViewStateSaver> saver(group);
         if (!d->mSelectionSavers.contains(groupName)) {
-            d->mSelectionSavers.insert(groupName, new KViewStateMaintainer<ETMViewStateSaver>(group));
+            d->mSelectionSavers.insert(groupName,
+                                       new KViewStateMaintainer<ETMViewStateSaver>(group));
             d->mSelectionSavers[groupName]->setSelectionModel(checkableProxyModel->selectionModel());
         }
         d->mSelectionSavers[groupName]->saveState();
