@@ -26,8 +26,11 @@
 #include "prefs.h"
 #include "prefs_base.h"
 
-#include <KSystemTimeZone>
 #include "calendarview_debug.h"
+
+#include <AkonadiCore/AttributeFactory>
+#include <AkonadiCore/CollectionColorAttribute>
+
 #include <QFontDatabase>
 
 using namespace EventViews;
@@ -63,12 +66,12 @@ QByteArray agendaViewIconDefaults()
     QByteArray iconDefaults;
 
     iconDefaults[EventViews::EventView::CalendarCustomIcon] = 1;
-    iconDefaults[EventViews::EventView::TaskIcon]           = 1;
-    iconDefaults[EventViews::EventView::JournalIcon]        = 1;
-    iconDefaults[EventViews::EventView::RecurringIcon]      = 1;
-    iconDefaults[EventViews::EventView::ReminderIcon]       = 1;
-    iconDefaults[EventViews::EventView::ReadOnlyIcon]       = 1;
-    iconDefaults[EventViews::EventView::ReplyIcon]          = 0;
+    iconDefaults[EventViews::EventView::TaskIcon] = 1;
+    iconDefaults[EventViews::EventView::JournalIcon] = 1;
+    iconDefaults[EventViews::EventView::RecurringIcon] = 1;
+    iconDefaults[EventViews::EventView::ReminderIcon] = 1;
+    iconDefaults[EventViews::EventView::ReadOnlyIcon] = 1;
+    iconDefaults[EventViews::EventView::ReplyIcon] = 0;
 
     return iconDefaults;
 }
@@ -78,12 +81,12 @@ QByteArray monthViewIconDefaults()
     QByteArray iconDefaults;
 
     iconDefaults[EventViews::EventView::CalendarCustomIcon] = 1;
-    iconDefaults[EventViews::EventView::TaskIcon]           = 1;
-    iconDefaults[EventViews::EventView::JournalIcon]        = 1;
-    iconDefaults[EventViews::EventView::RecurringIcon]      = 0;
-    iconDefaults[EventViews::EventView::ReminderIcon]       = 0;
-    iconDefaults[EventViews::EventView::ReadOnlyIcon]       = 1;
-    iconDefaults[EventViews::EventView::ReplyIcon]          = 0;
+    iconDefaults[EventViews::EventView::TaskIcon] = 1;
+    iconDefaults[EventViews::EventView::JournalIcon] = 1;
+    iconDefaults[EventViews::EventView::RecurringIcon] = 0;
+    iconDefaults[EventViews::EventView::ReminderIcon] = 0;
+    iconDefaults[EventViews::EventView::ReadOnlyIcon] = 1;
+    iconDefaults[EventViews::EventView::ReplyIcon] = 0;
 
     return iconDefaults;
 }
@@ -178,8 +181,8 @@ void BaseConfig::usrRead()
 #if 0
     config()->setGroup("FreeBusy");
     if (mRememberRetrievePw) {
-        mRetrievePassword =
-            KStringHandler::obscure(config()->readEntry("Retrieve Server Password"));
+        mRetrievePassword
+            = KStringHandler::obscure(config()->readEntry("Retrieve Server Password"));
     }
 #endif
 
@@ -188,10 +191,10 @@ void BaseConfig::usrRead()
 
     KConfigGroup monthViewConfig(config(), "Month View");
     KConfigGroup agendaViewConfig(config(), "Agenda View");
-    const QByteArray agendaIconArray =
-        agendaViewConfig.readEntry<QByteArray>("agendaViewItemIcons", agendaViewIconDefaults());
-    const QByteArray monthIconArray =
-        monthViewConfig.readEntry<QByteArray>("monthViewItemIcons", monthViewIconDefaults());
+    const QByteArray agendaIconArray
+        = agendaViewConfig.readEntry<QByteArray>("agendaViewItemIcons", agendaViewIconDefaults());
+    const QByteArray monthIconArray
+        = monthViewConfig.readEntry<QByteArray>("monthViewItemIcons", monthViewIconDefaults());
 
     mAgendaViewIcons = iconArrayToSet(agendaIconArray);
     mMonthViewIcons = iconArrayToSet(monthIconArray);
@@ -201,8 +204,6 @@ void BaseConfig::usrRead()
 
 bool BaseConfig::usrSave()
 {
-    KConfigGroup generalConfig(config(), "General");
-
     KConfigGroup rColorsConfig(config(), "Resources Colors");
     QHash<QString, QColor>::const_iterator i = mResourceColors.constBegin();
     QHash<QString, QColor>::const_iterator end(mResourceColors.constEnd());
@@ -238,9 +239,17 @@ bool BaseConfig::usrSave()
 class Q_DECL_HIDDEN Prefs::Private
 {
 public:
-    Private(Prefs *parent) : mAppConfig(nullptr), q(parent) {}
+    Private(Prefs *parent)
+        : mAppConfig(nullptr)
+        , q(parent)
+    {
+    }
+
     Private(Prefs *parent, KCoreConfigSkeleton *appConfig)
-        : mAppConfig(appConfig), q(parent) {}
+        : mAppConfig(appConfig)
+        , q(parent)
+    {
+    }
 
     KConfigSkeletonItem *appConfigItem(const KConfigSkeletonItem *baseConfigItem) const;
 
@@ -256,8 +265,7 @@ public:
     void setDateTime(KCoreConfigSkeleton::ItemDateTime *baseConfigItem, const QDateTime &value);
     QDateTime getDateTime(const KCoreConfigSkeleton::ItemDateTime *baseConfigItem) const;
 
-    void setStringList(KCoreConfigSkeleton::ItemStringList *baseConfigItem,
-                       const QStringList &value);
+    void setStringList(KCoreConfigSkeleton::ItemStringList *baseConfigItem, const QStringList &value);
     QStringList getStringList(const KCoreConfigSkeleton::ItemStringList *baseConfigItem) const;
 
     void setColor(KConfigSkeleton::ItemColor *baseConfigItem, const QColor &value);
@@ -268,7 +276,7 @@ public:
 
 public:
     BaseConfig mBaseConfig;
-    KCoreConfigSkeleton *mAppConfig;
+    KCoreConfigSkeleton *mAppConfig = nullptr;
 
 private:
     Prefs *q;
@@ -290,11 +298,13 @@ void Prefs::Private::setBool(KCoreConfigSkeleton::ItemBool *baseConfigItem, bool
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemBool *item = dynamic_cast<KCoreConfigSkeleton::ItemBool *>(appItem);
+        KCoreConfigSkeleton::ItemBool *item
+            = dynamic_cast<KCoreConfigSkeleton::ItemBool *>(appItem);
         if (item) {
             item->setValue(value);
         } else {
-            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type Bool";
+            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                         << "is not of type Bool";
         }
     } else {
         baseConfigItem->setValue(value);
@@ -305,11 +315,13 @@ bool Prefs::Private::getBool(const KCoreConfigSkeleton::ItemBool *baseConfigItem
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemBool *item = dynamic_cast<KCoreConfigSkeleton::ItemBool *>(appItem);
+        KCoreConfigSkeleton::ItemBool *item
+            = dynamic_cast<KCoreConfigSkeleton::ItemBool *>(appItem);
         if (item) {
             return item->value();
         }
-        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type Bool";
+        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                     << "is not of type Bool";
     }
     return baseConfigItem->value();
 }
@@ -322,7 +334,8 @@ void Prefs::Private::setInt(KCoreConfigSkeleton::ItemInt *baseConfigItem, int va
         if (item) {
             item->setValue(value);
         } else {
-            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type Int";
+            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                         << "is not of type Int";
         }
     } else {
         baseConfigItem->setValue(value);
@@ -337,7 +350,8 @@ int Prefs::Private::getInt(const KCoreConfigSkeleton::ItemInt *baseConfigItem) c
         if (item) {
             return item->value();
         }
-        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type Int";
+        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                     << "is not of type Int";
     }
     return baseConfigItem->value();
 }
@@ -347,13 +361,14 @@ void Prefs::Private::setString(KCoreConfigSkeleton::ItemString *baseConfigItem,
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemString *item =
-            dynamic_cast<KCoreConfigSkeleton::ItemString *>(appItem);
+        KCoreConfigSkeleton::ItemString *item
+            = dynamic_cast<KCoreConfigSkeleton::ItemString *>(appItem);
 
         if (item) {
             item->setValue(value);
         } else {
-            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type String";
+            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                         << "is not of type String";
         }
     } else {
         baseConfigItem->setValue(value);
@@ -364,13 +379,14 @@ QString Prefs::Private::getString(const KCoreConfigSkeleton::ItemString *baseCon
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemString *item =
-            dynamic_cast<KCoreConfigSkeleton::ItemString *>(appItem);
+        KCoreConfigSkeleton::ItemString *item
+            = dynamic_cast<KCoreConfigSkeleton::ItemString *>(appItem);
 
         if (item) {
             return item->value();
         }
-        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type String";
+        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                     << "is not of type String";
     }
     return baseConfigItem->value();
 }
@@ -380,13 +396,14 @@ void Prefs::Private::setDateTime(KCoreConfigSkeleton::ItemDateTime *baseConfigIt
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemDateTime *item =
-            dynamic_cast<KCoreConfigSkeleton::ItemDateTime *>(appItem);
+        KCoreConfigSkeleton::ItemDateTime *item
+            = dynamic_cast<KCoreConfigSkeleton::ItemDateTime *>(appItem);
 
         if (item) {
             item->setValue(value);
         } else {
-            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type DateTime";
+            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                         << "is not of type DateTime";
         }
     } else {
         baseConfigItem->setValue(value);
@@ -398,13 +415,14 @@ QDateTime Prefs::Private::getDateTime(
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemDateTime *item =
-            dynamic_cast<KCoreConfigSkeleton::ItemDateTime *>(appItem);
+        KCoreConfigSkeleton::ItemDateTime *item
+            = dynamic_cast<KCoreConfigSkeleton::ItemDateTime *>(appItem);
 
         if (item) {
             return item->value();
         }
-        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type DateTime";
+        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                     << "is not of type DateTime";
     }
     return baseConfigItem->value();
 }
@@ -414,13 +432,14 @@ void Prefs::Private::setStringList(KCoreConfigSkeleton::ItemStringList *baseConf
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemStringList *item =
-            dynamic_cast<KCoreConfigSkeleton::ItemStringList *>(appItem);
+        KCoreConfigSkeleton::ItemStringList *item
+            = dynamic_cast<KCoreConfigSkeleton::ItemStringList *>(appItem);
 
         if (item) {
             item->setValue(value);
         } else {
-            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type StringList";
+            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                         << "is not of type StringList";
         }
     } else {
         baseConfigItem->setValue(value);
@@ -432,13 +451,14 @@ QStringList Prefs::Private::getStringList(
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemStringList *item =
-            dynamic_cast<KCoreConfigSkeleton::ItemStringList *>(appItem);
+        KCoreConfigSkeleton::ItemStringList *item
+            = dynamic_cast<KCoreConfigSkeleton::ItemStringList *>(appItem);
 
         if (item) {
             return item->value();
         }
-        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type StringList";
+        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                     << "is not of type StringList";
     }
     return baseConfigItem->value();
 }
@@ -451,7 +471,8 @@ void Prefs::Private::setColor(KConfigSkeleton::ItemColor *baseConfigItem, const
         if (item) {
             item->setValue(value);
         } else {
-            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type Color";
+            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                         << "is not of type Color";
         }
     } else {
         baseConfigItem->setValue(value);
@@ -466,7 +487,8 @@ QColor Prefs::Private::getColor(const KConfigSkeleton::ItemColor *baseConfigItem
         if (item) {
             return item->value();
         }
-        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type Color";
+        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                     << "is not of type Color";
     }
     return baseConfigItem->value();
 }
@@ -479,7 +501,8 @@ void Prefs::Private::setFont(KConfigSkeleton::ItemFont *baseConfigItem, const QF
         if (item) {
             item->setValue(value);
         } else {
-            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type Font";
+            qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                         << "is not of type Font";
         }
     } else {
         baseConfigItem->setValue(value);
@@ -494,17 +517,22 @@ QFont Prefs::Private::getFont(const KConfigSkeleton::ItemFont *baseConfigItem) c
         if (item) {
             return item->value();
         }
-        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name() << "is not of type Font";
+        qCCritical(CALENDARVIEW_LOG) << "Application config item" << appItem->name()
+                                     << "is not of type Font";
     }
     return baseConfigItem->value();
 }
 
 Prefs::Prefs() : d(new Private(this))
 {
+    // necessary to use CollectionColorAttribute in the EventViews::resourceColor and EventViews::setResourceColor
+    Akonadi::AttributeFactory::registerAttribute<Akonadi::CollectionColorAttribute>();
 }
 
 Prefs::Prefs(KCoreConfigSkeleton *appConfig) : d(new Private(this, appConfig))
 {
+    // necessary to use CollectionColorAttribute in the EventViews::resourceColor and EventViews::setResourceColor
+    Akonadi::AttributeFactory::registerAttribute<Akonadi::CollectionColorAttribute>();
 }
 
 Prefs::~Prefs()
@@ -588,6 +616,16 @@ QDateTime Prefs::dayBegins() const
     return d->getDateTime(d->mBaseConfig.dayBeginsItem());
 }
 
+void Prefs::setFirstDayOfWeek(const int day)
+{
+    d->setInt(d->mBaseConfig.weekStartDayItem(), day - 1);
+}
+
+int Prefs::firstDayOfWeek() const
+{
+    return d->getInt(d->mBaseConfig.weekStartDayItem()) + 1;
+}
+
 void Prefs::setWorkingHoursStart(const QDateTime &dateTime)
 {
     d->setDateTime(d->mBaseConfig.workingHoursStartItem(), dateTime);
@@ -828,11 +866,6 @@ QFont Prefs::agendaTimeLabelsFont() const
     return d->getFont(d->mBaseConfig.agendaTimeLabelsFontItem());
 }
 
-KDateTime::Spec Prefs::timeSpec() const
-{
-    return KSystemTimeZones::local();
-}
-
 QTimeZone Prefs::timeZone() const
 {
     return QTimeZone::systemTimeZone();
@@ -922,6 +955,7 @@ void Prefs::setResourceColor(const QString &cal, const QColor &color)
 {
     d->mBaseConfig.setResourceColor(cal, color);
 }
+
 #define USE_RANDOM
 void Prefs::createNewColor(QColor &defColor, int seed)
 {
@@ -941,8 +975,7 @@ void Prefs::createNewColor(QColor &defColor, int seed)
 QColor Prefs::resourceColorKnown(const QString &cal) const
 {
     QColor color;
-    if (!cal.isEmpty()  &&
-            d->mBaseConfig.mResourceColors.contains(cal)) {
+    if (!cal.isEmpty() && d->mBaseConfig.mResourceColors.contains(cal)) {
         color = d->mBaseConfig.mResourceColors.value(cal);
     }
     return color;
@@ -957,8 +990,7 @@ QColor Prefs::resourceColor(const QString &cal)
     QColor color = resourceColorKnown(cal);
 
     // assign default color if enabled
-    if (!color.isValid() &&
-            d->getBool(d->mBaseConfig.assignDefaultResourceColorsItem())) {
+    if (!color.isValid() && d->getBool(d->mBaseConfig.assignDefaultResourceColorsItem())) {
         QColor defColor(0x37, 0x7A, 0xBC);
         const int seed = d->getInt(d->mBaseConfig.defaultResourceColorSeedItem());
         const QStringList colors = d->getStringList(d->mBaseConfig.defaultResourceColorsItem());
